﻿using System.Drawing;

namespace LegoPixelSpaceInvaders
{
    public class Alien
    {
        private bool m_State;
        private Point m_Position;
        private bool m_Idle;
        private int m_Delay;
        private Color m_Color;
        private bool m_PlaySound;
        private bool m_Nuclear;
        private int m_StateDelay;

        public bool Idle
        {
            get { return m_Idle; }
            set
            {
                m_PlaySound = true;
                m_Idle = value;
                m_Delay = 1;
                m_Color = Color.White;
            }
        }

        public Point Position { get { return m_Position; } set { m_Position = value; } }
        public Color Color { get { return m_Color; } set { m_Color = value; } }

        public Alien(bool state, Point position)
        {
            m_Idle = false;
            m_State = state;
            m_Position = position;
            m_Color = Color.White;
        }

        public void NuclearKill()
        {
            m_Idle = true;
            m_Delay = 10;
            m_Color = Color.Black;
        }

        public void NuclearSurvive()
        {
            m_Nuclear = true;
        }

        public bool IsInside(Projectile p)
        {
            if (!m_Idle)
            {
                if (p.Position.X >= m_Position.X && p.Position.X < m_Position.X + 11)
                {
                    if (p.Position.Y >= m_Position.Y && p.Position.Y < m_Position.Y + 8)
                        return true;
                }
            }

            return false;
        }

        public bool IsInside(Missile m)
        {
            if (!m_Idle)
            {
                if (m.Position.X >= m_Position.X - 2 && m.Position.X < m_Position.X + 13)
                {
                    if (m.Position.Y >= m_Position.Y && m.Position.Y < m_Position.Y + 8)
                        return true;
                }
            }

            return false;
        }

        public void Update(IAudioContext context)
        {
            if (m_PlaySound)
            {
                float balance = (float)Position.X / 113.0f;
                balance *= 200;
                balance -= 100;

                context.PlaySound("platsch", (int)balance);
                m_PlaySound = false;
            }

            if (m_Nuclear)
            {
                if (m_Color.B > 10)
                    m_Color = Color.FromArgb(m_Color.R, m_Color.G, m_Color.B - 10);
                else
                    m_Color = Color.Yellow;
            }

            if (m_StateDelay > 3)
            {
                m_State = !m_State;
                m_StateDelay = 0;
            }
            else
                m_StateDelay++;

            if (m_Delay > 0)
                m_Delay--;
        }

        public void Draw(IDrawingContext context)
        {
            if (m_Idle)
            {
                if (m_Delay > 0)
                {
                    context.DrawPixel(m_Position.X + 3, m_Position.Y, m_Color);
                    context.DrawPixel(m_Position.X + 7, m_Position.Y, m_Color);
                    context.DrawPixel(m_Position.X, m_Position.Y + 1, m_Color);
                    context.DrawPixel(m_Position.X + 4, m_Position.Y + 1, m_Color);
                    context.DrawPixel(m_Position.X + 6, m_Position.Y + 1, m_Color);
                    context.DrawPixel(m_Position.X + 10, m_Position.Y + 1, m_Color);
                    context.DrawPixel(m_Position.X + 1, m_Position.Y + 2, m_Color);
                    context.DrawPixel(m_Position.X + 9, m_Position.Y + 2, m_Color);
                    context.DrawPixel(m_Position.X + 2, m_Position.Y + 3, m_Color);
                    context.DrawPixel(m_Position.X + 8, m_Position.Y + 3, m_Color);
                    context.DrawPixel(m_Position.X - 1, m_Position.Y + 4, m_Color);
                    context.DrawPixel(m_Position.X, m_Position.Y + 4, m_Color);
                    context.DrawPixel(m_Position.X + 10, m_Position.Y + 4, m_Color);
                    context.DrawPixel(m_Position.X + 11, m_Position.Y + 4, m_Color);
                    context.DrawPixel(m_Position.X + 2, m_Position.Y + 5, m_Color);
                    context.DrawPixel(m_Position.X + 8, m_Position.Y + 5, m_Color);
                    context.DrawPixel(m_Position.X + 1, m_Position.Y + 6, m_Color);
                    context.DrawPixel(m_Position.X + 9, m_Position.Y + 6, m_Color);
                    context.DrawPixel(m_Position.X, m_Position.Y + 7, m_Color);
                    context.DrawPixel(m_Position.X + 4, m_Position.Y + 7, m_Color);
                    context.DrawPixel(m_Position.X + 6, m_Position.Y + 7, m_Color);
                    context.DrawPixel(m_Position.X + 10, m_Position.Y + 7, m_Color);
                    context.DrawPixel(m_Position.X + 3, m_Position.Y + 8, m_Color);
                    context.DrawPixel(m_Position.X + 7, m_Position.Y + 8, m_Color);
                }
            }
            else if (m_State)
            {
                context.DrawPixel(m_Position.X + 2, m_Position.Y, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 1, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 1, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 6, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 6, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 6, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 6, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 7, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 7, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 7, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 7, m_Color);
            }
            else
            {
                context.DrawPixel(m_Position.X + 2, m_Position.Y, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 1, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 1, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 1, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 1, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 2, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 3, m_Color);
                context.DrawPixel(m_Position.X + 0, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 10, m_Position.Y + 4, m_Color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 3, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 4, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 5, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 6, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 7, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 5, m_Color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 6, m_Color);
                context.DrawPixel(m_Position.X + 8, m_Position.Y + 6, m_Color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 7, m_Color);
                context.DrawPixel(m_Position.X + 9, m_Position.Y + 7, m_Color);
            }
        }
    }
}
