﻿using System.Drawing;

namespace LegoPixelSpaceInvaders
{
    public class Missile
    {
        private Point m_Position;
        private bool m_Idle;
        private bool m_State;
        private bool m_PlaySound;

        public bool Idle { get { return m_Idle; } set { m_Idle = value; } }

        public Point Position
        {
            get
            {
                if (m_Idle)
                    return new Point(-10, -10);

                return m_Position;
            }
            set
            {
                if (m_Idle)
                {
                    m_PlaySound = true;
                    m_Position = value;
                    m_Idle = false;
                    m_State = false;
                }
            }
        }

        public Missile()
        {
            m_Idle = true;
        }

        public void Update(IAudioContext context)
        {
            if (m_PlaySound)
            {
                float balance = Position.X / 113.0f;
                balance *= 200;
                balance -= 100;

                context.PlaySound("rocket", (int)balance);
                m_PlaySound = false;
            }

            m_State = !m_State;

            if(!m_Idle)
                m_Position.Y -= 1;

            if (m_Position.Y < -10)
                m_Idle = true;
        }

        public void Draw(IDrawingContext context)
        {
            if (!m_Idle)
            {
                Color color = Color.White;
                context.DrawPixel(m_Position.X, m_Position.Y, color);
                context.DrawPixel(m_Position.X - 1, m_Position.Y + 1, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 1, color);
                context.DrawPixel(m_Position.X - 1, m_Position.Y + 2, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 2, color);
                context.DrawPixel(m_Position.X - 1, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 3, color);
                context.DrawPixel(m_Position.X - 1, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 4, color);
                context.DrawPixel(m_Position.X - 2, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X - 1, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 1, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 5, color);
                context.DrawPixel(m_Position.X - 2, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X, m_Position.Y + 6, color);
                context.DrawPixel(m_Position.X + 2, m_Position.Y + 6, color);

                if (m_State)
                {
                    context.DrawPixel(m_Position.X - 2, m_Position.Y + 8, color);
                    context.DrawPixel(m_Position.X, m_Position.Y + 8, color);
                    context.DrawPixel(m_Position.X + 2, m_Position.Y + 8, color);
                    context.DrawPixel(m_Position.X, m_Position.Y + 9, color);
                    context.DrawPixel(m_Position.X - 3, m_Position.Y + 9, color);
                    context.DrawPixel(m_Position.X + 3, m_Position.Y + 9, color);
                }
            }
        }
    }
}